Package: SWATH2stats
Type: Package
Title: Transform and Filter SWATH Data for Statistical Packages
Version: 1.42.0
Date: 2025-12-17
Authors@R: c(person("Peter", "Blattmann", role = c("aut", "cre"),
                    email="peter_blattmann@bluewin.ch",
                    comment = c(ORCID = "0000-0001-9105-6381")), 
             person("Moritz", "Heusel", role = c("aut"),
                    comment = c(ORCID = "0000-0002-8506-530X")),
             person("Ruedi", "Aebersold", role = c("aut"),
                    comment = c(ORCID = "0000-0002-9576-3267")))
Author: Peter Blattmann [aut, cre]
  Moritz Heusel [aut]
  Ruedi Aebersold [aut]
Maintainer: Peter Blattmann <peter_blattmann@bluewin.ch>
Description: This package is intended to transform SWATH data from the
    OpenSWATH software into a format readable by other statistics
    packages while performing filtering, annotation and FDR estimation.
License: GPL-3
Depends: R(>= 2.10.0)
Imports: data.table, reshape2, ggplot2, stats, grDevices, graphics,
        utils, biomaRt, methods
Suggests: testthat, knitr, rmarkdown
Enhances: MSstats, PECA, aLFQ
biocViews: Proteomics, Annotation, ExperimentalDesign, Preprocessing,
        MassSpectrometry, ImmunoOncology
NeedsCompilation: no
VignetteBuilder: knitr
RoxygenNote: 7.3.3
Encoding: UTF-8
URL: https://peterblattmann.github.io/SWATH2stats/
BugReports: https://github.com/peterblattmann/SWATH2stats
git_url: https://git.bioconductor.org/packages/SWATH2stats
git_branch: RELEASE_3_23
git_last_commit: 402b2fc
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
Packaged: 2026-04-29 01:04:26 UTC; biocbuild
