# Generated by roxygen2: do not edit by hand

S3method(plot,fdr_cube)
S3method(plot,fdr_table)
export(JPP_update)
export(add_genesymbol)
export(assess_decoy_rate)
export(assess_fdr_byrun)
export(assess_fdr_overall)
export(convert4MSstats)
export(convert4PECA)
export(convert4aLFQ)
export(convert4mapDIA)
export(convert4pythonscript)
export(convert_protein_ids)
export(count_analytes)
export(disaggregate)
export(filter_all_peptides)
export(filter_mscore)
export(filter_mscore_condition)
export(filter_mscore_fdr)
export(filter_mscore_freqobs)
export(filter_on_max_peptides)
export(filter_on_min_peptides)
export(filter_proteotypic_peptides)
export(import_data)
export(load_mart)
export(mscore4assayfdr)
export(mscore4pepfdr)
export(mscore4protfdr)
export(plot_correlation_between_samples)
export(plot_variation)
export(plot_variation_vs_total)
export(reduce_OpenSWATH_output)
export(removeDecoyProteins)
export(sample_annotation)
export(transform_MSstats_OpenSWATH)
export(unifyProteinGroupLabels)
export(validate_columns)
export(write_matrix_peptides)
export(write_matrix_proteins)
importFrom(biomaRt,getBM)
importFrom(biomaRt,listDatasets)
importFrom(biomaRt,listMarts)
importFrom(biomaRt,useMart)
importFrom(data.table,data.table)
importFrom(data.table,fread)
importFrom(data.table,setkey)
importFrom(data.table,setkeyv)
importFrom(data.table,setnames)
importFrom(ggplot2,aes)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_boxplot)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,geom_violin)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_fill_gradient)
importFrom(ggplot2,scale_x_discrete)
importFrom(ggplot2,scale_y_discrete)
importFrom(ggplot2,stat_summary)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,grid)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(methods,is)
importFrom(reshape2,colsplit)
importFrom(reshape2,dcast)
importFrom(reshape2,melt)
importFrom(stats,aggregate)
importFrom(stats,cor)
importFrom(stats,density)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,sd)
importFrom(utils,head)
importFrom(utils,write.csv)
importFrom(utils,write.table)
